require 'rubygems'
require 'curb'
require 'json'

def print_report_data(data)
  title = data['title']
  project = data['project']
  puts "Report #{title} (#{project}) is #{data['status']}"
  header_line = data['pages']['columns'].join("\t")
  puts header_line
  puts "=" * header_line.length
  data['pages']['data'].each{|line| puts line.join("\t")}
end

def get_report_status()
  api_url = 'http://app.linkresearchtools.com/toolkit/api.php'
  
  get_data_request_data = [Curl::PostField.content('api_key', 'your-api-key'),
    Curl::PostField.content('action', 'get_data'),
    Curl::PostField.content('report_id', '10084974')]
  res = Curl::Easy.http_post(api_url, *get_data_request_data)
  case res.response_code
  when 200
    result = JSON.parse(res.body_str)
    case result['status']
    when 100
      case result['report']['status']
      when 'New'
      when 'Queued'
        puts "Waiting for report to be started"
        return false
      
      when 'In Progress'
        overall = result['report']['progress_overall']
        done = result['report']['progress_done']
        if overall == 0
          return false
        end
        percent_done = (Float(done) / Float(overall) * 100.0).round
        puts "Processing: #{percent_done}% done"
        return false
        
      when 'Done'
        print_report_data(result['report'])
        return true
      when 'Terminated'
        print_report_data(result['report'])
        return true
      when 'Done with errors'
        print_report_data(result['report'])
        return true
      
      else
        puts "Oops, report status is #{result['report']['status']}."
        return true
      end
      
    else
      puts "Oops, got an error"
      puts "(#{result['status']}) #{result['message']}"
      return true
    end
  else
    puts "Oops, got an error response"
    return true
  end
end

while not get_report_status()
  sleep(5)
end
