require 'net/http'
require 'uri'
require 'rubygems'
require 'json'

def print_report_data(data)
  title = data['title']
  project = data['project']
  puts "Report #{title} (#{project}) is #{data['status']}"
  header_line = data['pages']['columns'].join("\t")
  puts header_line
  puts "=" * header_line.length
  data['pages']['data'].each{|line| puts line.join("\t")}
end

def get_report_status()
  api_url = 'http://app.linkresearchtools.com/toolkit/api.php'

  get_data_request_data = {'api_key' => 'your-api-key',
    'action' => 'get_data',
    'report_id' => '28448'}
  res = Net::HTTP.post_form(URI.parse(api_url), get_data_request_data)
  case res
  when Net::HTTPSuccess
    result = JSON.parse(res.body)
    case result['status']
    when 100
      case result['report']['status']
      when 'New'
      when 'Queued'
        puts "Waiting for report to be started"
        return false
      
      when 'In Progress'
        overall = result['report']['progress_overall']
        done = result['report']['progress_done']
        if overall == 0
          return false
        end
        percent_done = (Float(done) / Float(overall) * 100.0).round
        puts "Processing: #{percent_done}% done"
        return false
        
      when 'Done'
        print_report_data(result['report'])
        return true
      when 'Terminated'
        print_report_data(result['report'])
        return true
      when 'Done with errors'
        print_report_data(result['report'])
        return true
      
      else
        puts "Oops, report status is #{result['report']['status']}."
        return true
      end
      
    else
      puts "Oops, got an error"
      puts "(#{result['status']}) #{result['message']}"
      return true
    end
  else
    puts "Oops, got an error response"
    return true
  end
end

while not get_report_status()
  sleep(5)
end
